.. punchbowl documentation master file, created by
   sphinx-quickstart on Fri Nov 10 00:25:21 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to punchbowl's documentation!
=====================================

- We recommend beginning with the `introduction <intro.html>`_ and working through the related concepts.
- When you're ready to begin, read through documentation on how to `get data <data/index.html>`_.
- Check out the `examples <auto_examples/index.html>`_ tab for performing specific tasks.
- To understand a specific part of the pipeline, look in the `segment descriptions <pipeline/index.html>`_.
- Explore the `full API <autoapi/index.html>`_ for full details on functions.

.. toctree::
   :hidden:

   intro
   data/index
   pipeline/index
   auto_examples/index
   help
   contribute
   automation/index
